@@ -378,7 +378,7 @@ def purge_original(files):
             f.delete(file['file_path_exif_copy'])
 
 def get_keywords(files):
-    print(f"")
+    # print(f"")
     keywords = []
     file_array = _parse_file_obj_list(files)
     # print(f"get_keywords 1: ",keywords)
@@ -598,7 +598,7 @@ def apply_synonyms(file_keys,synonyms):
                 print(f"k: {k}:{v}")
                 new_file_keys.extend(new_keys)
                 print(f"new_file_keys: {new_file_keys}")
-                print(f"")
+                # print(f"")
         
     if len(new_file_keys) > 1:
         new_file_keys = list(set(new_file_keys))
@@ -611,27 +611,53 @@ def apply_synonyms(file_keys,synonyms):
         return new_file_keys
 
 def auto_tag_by_folder_name(watch_path,**kwargs):
+    '''
+        Watch a directory of images and apply the folder name to the image(s) when they are moved.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `watch_path` {str}
+            The path to the directory that will be watched.
+
+        Keyword Arguments
+        -------------------------
+        [`synonyms`=False] {dict}
+            A dictionary of synonyms that will be applied if a matching keyword is found.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 02-05-2022 10:00:34
+        `memberOf`: file_image
+        `version`: 1.0
+        `method_name`: auto_tag_by_folder_name
+    '''
     print(f"auto_tag_by_folder_name")
     synonyms = obj.get_kwarg(['synonyms'],False,(bool,dict),**kwargs)
+    apply_current_tags = obj.get_kwarg(['apply_current_tags'],False,(bool),**kwargs)
     print(f"Indexing images in {watch_path}")
     all_files = f.get_files(watch_path, ext="images",include_meta_data=True)
     print(f"Watching {len(all_files)} files")
     # duration = 0
 
+    if apply_current_tags is True:
+        apply_current_folders_as_tag(all_files)
+
     while True:
         time.sleep(.5)
         if len(all_files) == 0:
             all_files = f.get_files(watch_path, ext="images",include_meta_data=True)
         # duration += .5
-        # if duration % 10 == 0:
+        # if duration % 30 == 0:
         #     transferCompleteImages.transferCompleteImages()
         #     transferDLToOrg()
         #     convertOrgFolder()
         moved_files = []
         new_all_files = []
         update_files = []
-        
-        
+
         for file in all_files:
             # if the file does not exist, append it to the moved_files list.
             if f.exists(file['file_path']) is False:
@@ -644,7 +670,7 @@ def auto_tag_by_folder_name(watch_path,**kwargs):
             # search for the file by its name
             result = f.search.by_name(file['file_name'], watch_path)
             if result is not None:
-                print(f"result: {result}")
+                # print(f"result: {result}")
                 # get the file data, essentially update its paths and such.
                 file_data = f.get_data(result[0])
                 # append the file to the update_files array
@@ -657,7 +683,24 @@ def auto_tag_by_folder_name(watch_path,**kwargs):
         
         new_all_files.extend(new_files)
         all_files = new_all_files    
-    
+
+def apply_current_folders_as_tag(files,**kwargs):
+    save = obj.get_kwarg(['save'],False,(bool),**kwargs)
+    if f.directory.exists(files):
+        files = f.get_files(files, ext="images",include_meta_data=True)
+    # if files is False:
+    files_array = _parse_file_obj_list(files)
+    update_array = []
+    # new_file_array = []
+    for file in files_array:
+        # parse the folder name from the file object
+        dir_name = os.path.basename(file['dir_path'])
+        file = add_keyword(file,dir_name,save=False)[0]
+        update_array.append(file)
+    if save is True:
+        save_file_obj(update_array)
+    return files_array
+
 def _tag_by_folder_name(files,exclude='',**kwargs):
     save = obj.get_kwarg(['save'],False,(bool),**kwargs)
     if isinstance(exclude,(str)):
@@ -671,8 +714,6 @@ def _tag_by_folder_name(files,exclude='',**kwargs):
         if dir_name not in exclude:
             file = add_keyword(file,dir_name,save=False)[0]
             update_array.append(file)
-            
-            
         # new_file_array.append(file)
     # new_file_array = applyKeywordSynonyms(new_file_array)
     # update_files(new_file_array)
@@ -683,7 +724,7 @@ def _tag_by_folder_name(files,exclude='',**kwargs):
 def tag_if_missing_keyword(files,needles,keyword,**kwargs):
     update_array = []
     files_array = _parse_file_obj_list(files)
-    print(f"")
+    # print(f"")
     # get all of the files with a needle in their keywords.
     has_needle = has_keyword(files_array,needles)
     # get all of the files that already have the "keyword" and a needle
